@@ -1,12 +1,10 @@
-#include "cppr.h"
-#include "ldat.h"
-#include "lvec.h"
+#include "../inst/include/lvec.h"
 #include "r_export.h"
 
 class type_visitor : public ldat::lvec_visitor {
   public: 
 
-    type_visitor() : result_(cppr::na<std::string>()) {
+    type_visitor() : result_(ldat::na<std::string>()) {
     }
 
     void visit(ldat::lvec<double>& vec) {
@@ -17,7 +15,7 @@ class type_visitor : public ldat::lvec_visitor {
       result_ = "integer";
     }
 
-    void visit(ldat::lvec<cppr::boolean>& vec) {
+    void visit(ldat::lvec<ldat::boolean>& vec) {
       result_ = "logical";
     }
 
@@ -34,17 +32,12 @@ class type_visitor : public ldat::lvec_visitor {
 };
 
 
-extern "C" {
-  SEXP get_type(SEXP rv) {
-    CPPRTRY
-    type_visitor visitor{};
-    ldat::vec* v = sexp_to_vec(rv);
-    v->visit(&visitor);
-    cppr::rvec<cppr::character> result{1};
-    result[0] = visitor.result();
-    return result.sexp();
-    CPPRCATCH
-  }
+RcppExport SEXP get_type(SEXP rv) {
+  BEGIN_RCPP
+  type_visitor visitor;
+  Rcpp::XPtr<ldat::vec> v(rv);
+  v->visit(&visitor);
+  return Rcpp::wrap(visitor.result());
+  END_RCPP
 }
 
-
